@@ -13,7 +13,7 @@ def test_create_automaton():
     tes = pqca.tessellation.one_dimensional(10, 2)
     automaton = pqca.Automaton(
         [0]*10, [pqca.UpdateFrame(tes, qiskit_circuit=cx_circuit)], lambda x: [1]*10)
-    assert automaton.iterate() == [[1]*10]
+    assert next(automaton) == [1]*10
     assert len(str(automaton)) > 0
 
 
@@ -22,10 +22,6 @@ def test_aer_backend():
     cx_circuit = qiskit.QuantumCircuit(2)
     cx_circuit.cx(0, 1)
     tes = pqca.tessellation.one_dimensional(4, 2)
-
-    def backend(circuit):
-        return pqca.backend.Aer(circuit, "qasm_simulator")
-
     automaton = pqca.Automaton(
-        [1]*4, [pqca.UpdateFrame(tes, qiskit_circuit=cx_circuit)], backend)
-    assert automaton.iterate() == [[1, 0]*2]
+        [1]*4, [pqca.UpdateFrame(tes, qiskit_circuit=cx_circuit)], pqca.backend.qiskit())
+    assert next(automaton) == [1, 0]*2
